@@ -20,6 +20,7 @@ module Braintree
       attr_reader :last_4
       attr_reader :payroll
       attr_reader :prepaid
+      attr_reader :prepaid_reloadable
       attr_reader :product_id
       attr_reader :token
 
@@ -32,8 +33,10 @@ module Braintree
       end
 
       def inspect
-        attr_order = [:token, :bin, :last_4, :card_type, :expiration_date, :cardholder_name, :customer_location, :prepaid,
-        :healthcare, :durbin_regulated, :debit, :commercial, :payroll, :product_id, :country_of_issuance, :issuing_bank, :image_url, :call_id]
+        attr_order = [
+          :bin, :call_id, :card_type, :cardholder_name, :commercial, :country_of_issuance, :customer_location,
+          :debit, :durbin_regulated, :expiration_date, :healthcare, :image_url, :issuing_bank, :last_4, :payroll,
+          :prepaid, :prepaid_reloadable, :product_id, :token]
         formatted_attrs = attr_order.map do |attr|
           "#{attr}: #{send(attr).inspect}"
         end
